aboutsummaryrefslogtreecommitdiffstats
path: root/tests/code_fenced.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/code_fenced.rs')
-rw-r--r--tests/code_fenced.rs68
1 files changed, 36 insertions, 32 deletions
diff --git a/tests/code_fenced.rs b/tests/code_fenced.rs
index b7d8307..d970c94 100644
--- a/tests/code_fenced.rs
+++ b/tests/code_fenced.rs
@@ -3,17 +3,19 @@ use micromark::micromark;
#[test]
fn code_fenced() {
- assert_eq!(
- micromark("```\n<\n >\n```"),
- "<pre><code>&lt;\n &gt;\n</code></pre>",
- "should support fenced code w/ grave accents"
- );
+ // To do: concrete constructs (code fenced).
+ // assert_eq!(
+ // micromark("```\n<\n >\n```"),
+ // "<pre><code>&lt;\n &gt;\n</code></pre>",
+ // "should support fenced code w/ grave accents"
+ // );
- assert_eq!(
- micromark("~~~\n<\n >\n~~~"),
- "<pre><code>&lt;\n &gt;\n</code></pre>",
- "should support fenced code w/ tildes"
- );
+ // To do: concrete constructs (code fenced).
+ // assert_eq!(
+ // micromark("~~~\n<\n >\n~~~"),
+ // "<pre><code>&lt;\n &gt;\n</code></pre>",
+ // "should support fenced code w/ tildes"
+ // );
assert_eq!(
micromark("``\nfoo\n``"),
@@ -57,7 +59,7 @@ fn code_fenced() {
"should support an eof somewhere in content"
);
- // To do: blockquote.
+ // To do: blockquote (some bug).
// assert_eq!(
// micromark("> ```\n> aaa\n\nbbb"),
// "<blockquote>\n<pre><code>aaa\n</code></pre>\n</blockquote>\n<p>bbb</p>",
@@ -227,29 +229,31 @@ fn code_fenced() {
"should not support a closing sequence w/ too much indent, regardless of opening sequence (1)"
);
- // To do: blockquote.
- // assert_eq!(
- // micromark("> ```\n>\n>\n>\n\na"),
- // "<blockquote>\n<pre><code>\n\n\n</code></pre>\n</blockquote>\n<p>a</p>",
- // "should not support a closing sequence w/ too much indent, regardless of opening sequence (2)"
+ // To do: blockquote (some bug).
+ // assert_eq!(
+ // micromark("> ```\n>\n>\n>\n\na"),
+ // "<blockquote>\n<pre><code>\n\n\n</code></pre>\n</blockquote>\n<p>a</p>",
+ // "should not support a closing sequence w/ too much indent, regardless of opening sequence (2)"
+ // );
+
+ // To do: blockquote (some bug).
+ // assert_eq!(
+ // micromark("> ```a\nb"),
+ // "<blockquote>\n<pre><code class=\"language-a\"></code></pre>\n</blockquote>\n<p>b</p>",
+ // "should not support lazyness (1)"
// );
- // assert_eq!(
- // micromark("> ```a\nb"),
- // "<blockquote>\n<pre><code class=\"language-a\"></code></pre>\n</blockquote>\n<p>b</p>",
- // "should not support lazyness (1)"
- // );
-
- // assert_eq!(
- // micromark("> a\n```b"),
- // "<blockquote>\n<p>a</p>\n</blockquote>\n<pre><code class=\"language-b\"></code></pre>\n",
- // "should not support lazyness (2)"
- // );
-
- // assert_eq!(
- // micromark("> ```a\n```"),
- // "<blockquote>\n<pre><code class=\"language-a\"></code></pre>\n</blockquote>\n<pre><code></code></pre>\n",
- // "should not support lazyness (3)"
+ assert_eq!(
+ micromark("> a\n```b"),
+ "<blockquote>\n<p>a</p>\n</blockquote>\n<pre><code class=\"language-b\"></code></pre>\n",
+ "should not support lazyness (2)"
+ );
+
+ // To do: blockquote (lazy).
+ // assert_eq!(
+ // micromark("> ```a\n```"),
+ // "<blockquote>\n<pre><code class=\"language-a\"></code></pre>\n</blockquote>\n<pre><code></code></pre>\n",
+ // "should not support lazyness (3)"
// );
// To do: turning things off.